import torch
import torch.nn as nn


def conv_ops(in_ch, out_ch, ks=3, st=1, pd=1):
    return nn.Sequential(
        nn.Conv2d(in_ch, out_ch, kernel_size=ks, stride=st, padding=pd),
        nn.BatchNorm2d(out_ch),
        nn.ReLU()
    )


class Feature(nn.Module):
    def __init__(self):
        super().__init__()
        self.conv0 = conv_ops(3, 16)
        self.conv2 = conv_ops(16, 8)
        self.max_pool = nn.MaxPool2d(kernel_size=2, stride=2, padding=0)

    def forward(self, inputs):
        conv0 = self.conv0(inputs)
        max_pool0 = self.max_pool(conv0)
        conv2 = self.conv2(max_pool0)
        max_pool2 = self.max_pool(conv2)
        return max_pool2

class Net(nn.Module):
    def __init__(self):
        super().__init__()
        self.f = Feature()

    def forward(self, inputs):
        a = self.f(inputs)
        return a

net = Net()
dummy_input = torch.zeros(1, 3, 20, 40)
torch.onnx.export(net,
                  dummy_input,
                  "model.onnx",
                  input_names=["input"],
                  output_names=["output"],
                  verbose=False,
                  opset_version=11)